import React, { useEffect, useState } from 'react';
import { connect, history } from 'umi';
import {
  unstable_Form as Form,
  unstable_InputItem as InputItem,
  unstable_Button as Button,
  unstable_Toast as Toast
} from '@ant-design/mobile';
import styles from './index.less';
import { getImageVerifyCode, sendH5SmsCode, h5BySmsCodeLogin } from '../../serve/api';
const { Item } = Form;
type Imgobj = {
  image: String,
  imagecodeMd5: String
}
function Login(props: any) {
  const [inforObj, setInforObj] = useState<Imgobj>({ image: '', imagecodeMd5: '' });
  const [detectionCode, setDetectionCode] = useState<number>(60);
  const [loading, setLoading] = useState<boolean>(false);
  const [form] = Form.useForm();
  const { dispatch } = props;
  //登录按钮
  // const login = async (props: any) => {
  //   console.log(1);
  //   try {
  //     const { success, data } = await request(
  //       `/api-app/v1/user/getUserByUserNoOrNiceNo?params=${props.userNo}`,
  //     );
  //     if (success) {
  //       if (!data) {
  //         Toast.fail({
  //           content: '无效的用户ID',
  //         });
  //       } else {
  //         // 保存用户信息
  //         dispatch({
  //           type: 'global/saveUser',
  //           payload: data,
  //         });
  //         const backUrl = getQueryString('cb');
  //         if (backUrl) {
  //           history.replace(decodeURIComponent(backUrl));
  //         } else {
  //           history.replace('/vip');
  //         }
  //       }
  //     }
  //   } catch (error) {
  //     console.log(error);
  //   }
  // };

  const login = async () => {
    const { code, phone, imgCode } = form.getFieldsValue();
    if (!(/^1[3456789]\d{9}$/.test(phone))) {
      return Toast.info({ content: '请填写正确的手机号码', duration: 1 });
    }
    setLoading(true);
    try {
      const _params = {
        phone: phone,
        code: code,
        countryId: 86,
        imageCode: imgCode,
        imagecodeMd5: inforObj.imagecodeMd5
      }
      const { success, data } = await h5BySmsCodeLogin(_params);
      if (success) {
        window.localStorage.setItem('userInfo', JSON.stringify(data));
        Toast.success({ content: '登录成功', duration: 0.5 })
        setLoading(false);
        setTimeout(() => {
          history.push('/payRecharge');
        }, 1000);
      }
      else {
        setLoading(false);
      }
    } catch (error) {
      console.log(error);
    }
  }
  const onFinished = (err: any) => {
    Toast.fail({ content: err.errorFields[0].errors[0], duration: 1 });
  }
  //获取图片验证码
  const getImgcode = async () => {
    try {
      const { success, data } = await getImageVerifyCode({});
      if (success && data) {
        setInforObj({
          image: data.image,
          imagecodeMd5: data.imagecodeMd5
        })
      }
      else {
        Toast.fail({ content: data.msg });
      }
    } catch (error) {
      console.log(error);
    }
  }
  //发送验证码
  const onSendCode = async () => {
    if (detectionCode > 0 && detectionCode < 60) {
      return null;
    }
    const { imgCode, phone } = form.getFieldsValue();
    try {
      if (!(/^1[3456789]\d{9}$/.test(phone))) {
        return Toast.info({ content: '请填写正确的手机号码', duration: 1 });
      }
      else if (!imgCode) {
        return Toast.info({ content: '请填写图形验证码', duration: 1 });
      }
      let _params = {
        phone: phone,
        codeType: 101,
        imageCode: imgCode,
        imagecodeMd5: inforObj.imagecodeMd5,
        isDevSend: process.env.App_ENV === 'prod' ? false : true
      }
      const { success } = await sendH5SmsCode(_params);
      if (success) {
        Toast.success({ content: '发送验证码成功', duration: 1 });
        setDetectionCode(detectionCode - 1);
      }
    } catch (error) {
      console.log(error);
    }
  }
  useEffect(() => {
    let interval: any;
    if (detectionCode < 60) {
      interval = setInterval(() => {
        setDetectionCode(detectionCode - 1);
      }, 1000)
      if (detectionCode < 1) {
        clearInterval(interval);
        setDetectionCode(60);
      }
      return () => clearInterval(interval);
    }
  }, [detectionCode]);
  useEffect(() => {
    getImgcode();
  }, []);
  return (
    <div className={styles.login}>
      <Form form={form} onFinish={login} onFinishFailed={onFinished}>
        <Item name="phone" rules={[{ required: true, message: '请填写手机号码' }]}>
          <InputItem className={styles.input} placeholder='请输入手机号' />
        </Item>
        <Item name="imgCode" rules={[{ required: true, message: '请填写图形验证码' }]}>
          <div className={styles.input_wrap}>
            <InputItem
              placeholder='请输入图形验证码'
              className={styles.input_less}
            />
            <img
              onClick={getImgcode}
              className={styles.img_less}
              src={`data:image/jpg;base64,${inforObj.image}`}
              alt="" />
          </div>
        </Item>
        <Item name="code" rules={[{ required: true, message: '请填写短信验证码' }]}>
          <div className={styles.input_wrap}>
            <InputItem
              placeholder='请输入短信验证码'
              className={styles.input_less}
            />
            <div onClick={onSendCode}
              className={styles.send_code}>
              {(detectionCode > 0 && detectionCode < 60) ? detectionCode + 's' : '发送验证码'}
            </div>
          </div>
        </Item>
        <div style={{ marginTop: '12px' }}>
          <Button
            loadingText='正在登录'
            disabled={loading}
            loading={loading}
            type="primary"
            htmlType="submit"
            className={styles.button}
          >登录</Button>
        </div>
      </Form>
    </div>
  );
}

function mapStateToProps({ global }: any) {
  return { ...global };
}
export default connect(mapStateToProps)(Login);
